@@ -5,7 +5,7 @@
  */
  
 /*
- * Copyright (c) 2005 QUALCOMM Incorporated.  All rights reserved.
+ * Copyright (c) 2009 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  */
@@ -866,7 +866,7 @@ typedef struct {
                                  in pop_extend.c. Used by pop_parse
                                  for expansion. */
 enum { MAX_MDEF_INDEX = 10 };
-enum { MAX_MDEF_NAME  = 100 };
+enum { MAX_MDEF_LENGTH = 100 };
 
 
 MsgInfoList *msg_ptr ( POP *p, int msg_num );
